@@ -339,19 +339,20 @@ class LebaiRobot:
         self.rcs.SetClawForce(rc.Force(force=force))
         self.rcs.SetClawAmplitude(rc.Amplitude(amplitude=amplitude))
 
-    def movej(self, p, a=0, v=0, t=0, r=0, is_joint=None):
+    def movej(self, p: object, a: int = 0, v: int = 0, t: int = 0, r: int = 0, is_joint=None) -> None:
         """
         线性移动（关节空间）
 
-        :is_joint:
-        :p: `JointPose` 关节位置，`CartesianPose` 空间位置（将通过运动学反解转为关节位置）
-        :a: 主轴的关节加速度 (rad/s\ :sup:`2`)
+        :p: 传入JointPose或CartesianPose，JointPose` 关节位置，`CartesianPose` 空间位置（将通过运动学反解转为关节位置）
+        :a: 主轴的关节加速度 (rad/s)
         :v: 主轴的关节速度 (rad/s)
         :t: 运动时间 (s)
         :r: 交融半径 (m)
+        :is_joint: 已弃用
         """
-        if is_joint is None:
-            is_joint = getattr(p, 'is_joint', True)
+        if type(p) is not CartesianPose and type(p) is not JointPose:
+            raise Exception("请传入 CartesianPose 或 JointPose")
+        is_joint = getattr(p, 'is_joint', True)
         if not hasattr(p, 'pos'):
             p = JointPose(*p)
         req = rc.MoveJRequest(
@@ -370,15 +371,16 @@ class LebaiRobot:
         """
         线性移动（工具空间）
 
-        :p: `JointPose` 关节位置，`CartesianPose` 空间位置（将通过运动学反解转为关节位置）
-        :a: 轴的关节加速度 (rad/s\ :sup:`2`)
+        :p: 传入JointPose或CartesianPose，JointPose` 关节位置，`CartesianPose` 空间位置（将通过运动学反解转为关节位置）
+        :a: 轴的关节加速度 (rad/s)
         :v: 主轴的关节速度 (rad/s)
         :t: 运动时间 (s)
         :r: 交融半径 (m)
-        :is_joint:
+        :is_joint: 已弃用
         """
-        if is_joint is None:
-            is_joint = getattr(p, 'is_joint', False)
+        if type(p) is not CartesianPose and type(p) is not JointPose:
+            raise Exception("请传入 CartesianPose 或 JointPose")
+        is_joint = getattr(p, 'is_joint', False)
         if not hasattr(p, 'pos'):
             p = CartesianPose(*p)
         req = rc.MoveLRequest(
@@ -393,28 +395,32 @@ class LebaiRobot:
             p._base_set_PR(req.pose_base)
         self.rcs.MoveL(req)
 
-    def movec(self, via, p, rad=0, a=0, v=0, t=0, r=0, is_joint=None):
+    def movec(self, via: object, p: object, rad: int = 0, a: int = 0, v: int = 0, t: int = 0, r: int = 0, is_joint: bool = None) -> None:
         """
         圆弧移动（工具空间）
 
-        :param via:
-        :param p:
-        :param rad:
-        :param a:
-        :param v:
-        :param t:
-        :param r:
-        :param is_joint:
+        :param via: 途经位置。传入JointPose或CartesianPose，JointPose` 关节位置，`CartesianPose` 空间位置（将通过运动学反解转为关节位置）
+        :param p: 目标位置。入JointPose或CartesianPose，JointPose` 关节位置，`CartesianPose` 空间位置（将通过运动学反解转为关节位置）
+        :param rad: 路径圆弧的弧度 (rad)
+        :param a: 工具空间加速度 (m/s2)
+        :param v: 工具空间速度 (m/s)
+        :param t: 运动时间 (s)
+        :param r: 交融半径 (m)
+        :param is_joint: 已弃用
         """
+        if type(p) is not CartesianPose and type(p) is not JointPose:
+            raise Exception("p参数必须是 CartesianPose 或 JointPose 类型")
+        if type(via) is not CartesianPose and type(via) is not JointPose:
+            raise Exception("via 参数 必须是 CartesianPose 或 JointPose类型")
         if not hasattr(p, 'pos'):
             p = CartesianPose(*p)
         if not hasattr(via, 'pos'):
             via = CartesianPose(*via)
         req = rc.MoveCRequest(
             pose_via=list(via.pos),
-            pose_via_is_joint=is_joint if is_joint is not None else getattr(via, 'is_joint', True),
+            pose_via_is_joint=getattr(via, 'is_joint', True),
             pose_to=list(p.pos),
-            pose_to_is_joint=is_joint if is_joint is not None else getattr(p, 'is_joint', True),
+            pose_to_is_joint=getattr(p, 'is_joint', True),
             acceleration=a,
             velocity=v,
             time=t,
@@ -432,53 +438,58 @@ class LebaiRobot:
         """
         self.rcs.StopMove(Empty())
 
-    def move_pvat(self, p: list[float], v: list[float], a: list[float], t: float) -> None:
+    def move_pvat(self, p: list, v: list, a: list, t: float) -> None:
         """
         指定位置、速度、加速度、时间的伺服移动
 
-        :param p: 关节位置列表 (rad)
-        :param v: 关节速度列表 (rad/s)
-        :param a: 关节加速度列表 (rad/s^2)
+        :param p: 关节位置列表 (rad)，类型：list[float]
+        :param v: 关节速度列表 (rad/s)，类型：list[float]
+        :param a: 关节加速度列表 (rad/s^2)，类型：list[float]
         :param t: 总运动时间 (s)
         """
         self.rcs.MovePVAT(rc.PVATRequest(duration=t, q=p, v=v, acc=a))
 
-    def move_pvats(self, pvt_iter: list[PVAT]):
+    def move_pvats(self, pvt_iter: list) -> None:
+        """
+
+        @param pvt_iter: 类型：list[PVAT]
+        @type pvt_iter: list[PVAT]
+        """
         self.rcs.MovePVATStream((rc.PVATRequest(duration=s.duration, q=s.q, v=s.v, acc=s.acc) for s in pvt_iter))
 
-    def move_pvt(self, p: list[float], v: list[float], t: float):
+    def move_pvt(self, p: list, v: list, t: float) -> None:
         """
         指定位置、速度、时间的伺服移动, 加速度将自动计算。
 
-        :param p: 关节位置列表 (rad)
-        :param v: 关节速度列表 (rad/s)
+        :param p: 关节位置列表 (rad)，类型：list[float],
+        :param v: 关节速度列表 (rad/s)，类型：list[float],
         :param t: 总运动时间 (s)
         """
         self.rcs.MovePVT(rc.PVATRequest(duration=t, q=p, v=v))
 
-    def move_pvts(self, pvt_iter: list[PVAT]):
+    def move_pvts(self, pvt_iter: list):
         """
         指定位置、速度、时间的伺服移动, 加速度将自动计算。
 
-        :param pvt_iter:
+        :param pvt_iter: 类型：list[PVAT]
         :return:
         """
         self.rcs.MovePVTStream((rc.PVATRequest(duration=s.duration, q=s.q, v=s.v) for s in pvt_iter))
 
-    def move_pt(self, p: list[float], t: float) -> None:
+    def move_pt(self, p: list, t: float) -> None:
         """
         指定位置和时间的伺服移动,速度和加速度将自动计算。
 
-        :param p: 关节位置列表 (rad)
+        :param p: 关节位置列表 (rad)，类型：list[float]
         :param t: 总运动时间 (s)
         """
         self.rcs.MovePT(rc.PVATRequest(duration=t, q=p))
 
-    def move_pts(self, pt_iter: list[PVAT]):
+    def move_pts(self, pt_iter: list):
         """
         指定位置和时间的伺服移动,速度和加速度将自动计算。
 
-        :param pt_iter:
+        :param pt_iter: 类型：list[PVAT]
         :return:
         """
         self.rcs.MovePTStream((rc.PVATRequest(duration=s.duration, q=s.q) for s in pt_iter))
@@ -525,22 +536,22 @@ class LebaiRobot:
         """
         pass
 
-    def kinematics_forward(self, *p: list[float]):
+    def kinematics_forward(self, *p: list):
         """
         机器人正解
 
-        :param p:
+        :param p: 类型：list[float]
         :return:
         """
         j = JointPose(*p)
         res = self.rcs.KinematicsForward(j._to_Joint())
         return CartesianPose(*res.vector)
 
-    def kinematics_inverse(self, *p: list[float]):
+    def kinematics_inverse(self, *p: list):
         """
         机器人反解
 
-        :param p:
+        :param p:  类型：list[float]
         :return:
         """
         j = CartesianPose(*p)
@@ -581,7 +592,7 @@ class LebaiRobot:
         res = self.rcs.GetTargetJointPositions(Empty())
         return JointPose(*res.joints)
 
-    def get_actual_joint_speeds(self) -> tuple:
+    def get_actual_joint_speeds(self) -> list:
         """
         获得所有关节的实际角速度
 
@@ -589,9 +600,9 @@ class LebaiRobot:
         """
         self._sync()
         res = self.rcs.GetActualJointSpeeds(Empty())
-        return tuple(res.joints)
+        return list(res.joints)
 
-    def get_target_joint_speeds(self) -> tuple:
+    def get_target_joint_speeds(self) -> list:
         """
         获得所有关节的期望角速度
 
@@ -599,9 +610,9 @@ class LebaiRobot:
         """
         self._sync()
         res = self.rcs.GetTargetJointSpeeds(Empty())
-        return tuple(res.joints)
+        return list(res.joints)
 
-    def get_joint_torques(self) -> tuple:
+    def get_joint_torques(self) -> list:
         """
         获得每个关节的扭矩值
 
@@ -609,9 +620,9 @@ class LebaiRobot:
         """
         self._sync()
         res = self.rcs.GetJointTorques(Empty())
-        return tuple(res.joints)
+        return list(res.joints)
 
-    def get_actual_joint_torques(self) -> tuple:
+    def get_actual_joint_torques(self) -> list:
         """
         获取实际力矩
 
@@ -620,9 +631,9 @@ class LebaiRobot:
         """
         self._sync()
         res = self.rcs.GetRobotData(Empty())
-        return tuple(res.actualTorque.joints)
+        return list(res.actualTorque.joints)
 
-    def get_target_joint_torques(self) -> tuple:
+    def get_target_joint_torques(self) -> list:
         """
         获取理论力矩
 
@@ -630,9 +641,9 @@ class LebaiRobot:
         """
         self._sync()
         res = self.rcs.GetRobotData(Empty())
-        return tuple(res.targetTorque.joints)
+        return list(res.targetTorque.joints)
 
-    def get_joint_temperatures(self) -> tuple:
+    def get_joint_temperatures(self) -> list:
         """
         获取关节温度
 
@@ -640,7 +651,7 @@ class LebaiRobot:
         """
         self._sync()
         res = self.rcs.GetRobotData(Empty())
-        return tuple(res.jointTemps.joints)
+        return list(res.jointTemps.joints)
 
     def get_joint_temp(self, joint: int) -> float:
         """
@@ -813,13 +824,13 @@ class LebaiRobot:
         res = self.rcs.GetTcpDIO(msg.IOPin(pin=pin))
         return res.value
 
-    def set_led(self, mode: int, speed: float, color: list[int]) -> None:
+    def set_led(self, mode: int, speed: float, color: list) -> None:
         """
         设置LED灯状态
 
         :param mode: 1：关闭、2：常亮、3：呼吸、4：均分旋转、5：同色旋转、6：闪烁
         :param speed: 速度 分三个等级，1：快速、2：正常、3：慢速
-        :param color: 颜色，最多包含4个 0 ~ 15 之间的整数
+        :param color: 颜色，最多包含4个 0 ~ 15 之间的整数，类型：list[int]
         """
         self._sync()
         self.rcs.SetLED(msg.LEDStatus(mode=mode, speed=speed, color=color))
